collet.main


*env*clj

source

-mainclj

(-main & args)

Main entry point for the collet application. Receives the pipeline spec and config as arguments. Pipeline spec and config can be provided as a file path (local or S3) or a raw Clojure map.

Main entry point for the collet application.
Receives the pipeline spec and config as arguments.
Pipeline spec and config can be provided as a file path (local or S3) or a raw Clojure map.
sourceraw docstring

cli-optionsclj

source

coercecljmultimethod

Coerce a value to the type referenced by a symbol.

Coerce a value to the type referenced by a symbol.
sourceraw docstring

file-or-mapclj

(file-or-map target s)

Parses the provided string argument as a content of the file path or a raw Clojure map

Parses the provided string argument as a content of the file path or a raw Clojure map
sourceraw docstring

get-envclj

(get-env name)
(get-env name type & options)
source

include-specclj

(include-spec file-path path)
source

normalize-pathclj

(normalize-path base-path path)

If path is relative, make sure that it's relative to the main spec file

If path is relative, make sure that it's relative to the main spec file
sourceraw docstring

query->mapclj

(query->map query)

Turns a query string into a Clojure map with keyword keys

Turns a query string into a Clojure map with keyword keys
sourceraw docstring

read-config-fileclj

(read-config-file target uri)

Reads the content of the file from the provided URI

Reads the content of the file from the provided URI
sourceraw docstring

read-config-stringclj

(read-config-string target content)
(read-config-string target file-path content)
source

read-regexclj

(read-regex rgx)
source

s3-file-contentclj

(s3-file-content uri)

Reads the content of a file from S3

Reads the content of a file from S3
sourceraw docstring

start-publishersclj

(start-publishers)

Starts the publishers based on the provided configuration (environment variables)

Starts the publishers based on the provided configuration (environment variables)
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries