(-main & args)Main entry point for the collet application. Receives the pipeline spec and config as arguments. Pipeline spec and config can be provided as a file path (local or S3) or a raw Clojure map.
Main entry point for the collet application. Receives the pipeline spec and config as arguments. Pipeline spec and config can be provided as a file path (local or S3) or a raw Clojure map.
Coerce a value to the type referenced by a symbol.
Coerce a value to the type referenced by a symbol.
(file-or-map target s)Parses the provided string argument as a content of the file path or a raw Clojure map
Parses the provided string argument as a content of the file path or a raw Clojure map
(normalize-path base-path path)If path is relative, make sure that it's relative to the main spec file
If path is relative, make sure that it's relative to the main spec file
(query->map query)Turns a query string into a Clojure map with keyword keys
Turns a query string into a Clojure map with keyword keys
(read-config-file target uri)Reads the content of the file from the provided URI
Reads the content of the file from the provided URI
(read-config-string target content)(read-config-string target file-path content)(s3-file-content uri)Reads the content of a file from S3
Reads the content of a file from S3
(start-publishers)Starts the publishers based on the provided configuration (environment variables)
Starts the publishers based on the provided configuration (environment variables)
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |